==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/IntHandler.h <==
// class gnu.java.beans.decoder.IntHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class af6f058d499ddf04 gnu_java_beans_decoder_IntHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_IntHandler_H_
#define _JC_gnu_java_beans_decoder_IntHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_IntHandler$sub_refs	_jc_gnu_java_beans_decoder_IntHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$refs	_jc_gnu_java_beans_decoder_IntHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$nonrefs	_jc_gnu_java_beans_decoder_IntHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$object	_jc_gnu_java_beans_decoder_IntHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vmethods	_jc_gnu_java_beans_decoder_IntHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vtable	_jc_gnu_java_beans_decoder_IntHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vtype	_jc_gnu_java_beans_decoder_IntHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_IntHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_IntHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_IntHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_IntHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_IntHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_IntHandler$vmethods	gnu_java_beans_decoder_IntHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_IntHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_IntHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_IntHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_IntHandler$refs {
    _jc_gnu_java_beans_decoder_IntHandler$sub_refs	gnu_java_beans_decoder_IntHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_IntHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs	gnu_java_beans_decoder_IntHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_IntHandler$object {
	_jc_gnu_java_beans_decoder_IntHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_IntHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_IntHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_IntHandler$vtype _jc_gnu_java_beans_decoder_IntHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_IntHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_IntHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_IntHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/IntHandler.h <==
// class gnu.java.beans.decoder.IntHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class af6f058d499ddf04 gnu_java_beans_decoder_IntHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_IntHandler_H_
#define _JC_gnu_java_beans_decoder_IntHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_IntHandler$sub_refs	_jc_gnu_java_beans_decoder_IntHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$refs	_jc_gnu_java_beans_decoder_IntHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$nonrefs	_jc_gnu_java_beans_decoder_IntHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_IntHandler$object	_jc_gnu_java_beans_decoder_IntHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vmethods	_jc_gnu_java_beans_decoder_IntHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vtable	_jc_gnu_java_beans_decoder_IntHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_IntHandler$vtype	_jc_gnu_java_beans_decoder_IntHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_IntHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_IntHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_IntHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_IntHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_IntHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_IntHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_IntHandler$vmethods	gnu_java_beans_decoder_IntHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_IntHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_IntHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_IntHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_IntHandler$refs {
    _jc_gnu_java_beans_decoder_IntHandler$sub_refs	gnu_java_beans_decoder_IntHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_IntHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_IntHandler$sub_nonrefs	gnu_java_beans_decoder_IntHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_IntHandler$object {
	_jc_gnu_java_beans_decoder_IntHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_IntHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_IntHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_IntHandler$vtype _jc_gnu_java_beans_decoder_IntHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_IntHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_IntHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_IntHandler_H_ */
